@@ -9,9 +9,9 @@ function initialize!(integrator, cache::MagnusMidpointCache)
 end
 
 function perform_step!(integrator, cache::MagnusMidpointCache, repeat_step = false)
-    @unpack t, dt, uprev, u, p = integrator
+    (; t, dt, uprev, u, p) = integrator
     alg = unwrap_alg(integrator, nothing)
-    @unpack W, k, tmp, exp_cache = cache
+    (; W, k, tmp, exp_cache) = cache
     mass_matrix = integrator.f.mass_matrix
     exp_method = ExpMethodGeneric()
 
@@ -40,9 +40,9 @@ function initialize!(integrator, cache::LieRK4Cache)
 end
 
 function perform_step!(integrator, cache::LieRK4Cache, repeat_step = false)
-    @unpack t, dt, uprev, u, p = integrator
+    (; t, dt, uprev, u, p) = integrator
     alg = unwrap_alg(integrator, nothing)
-    @unpack W, k, tmp, exp_cache = cache
+    (; W, k, tmp, exp_cache) = cache
     mass_matrix = integrator.f.mass_matrix
     exp_method = ExpMethodGeneric()
 
@@ -92,9 +92,9 @@ function initialize!(integrator, cache::RKMK4Cache)
 end
 
 function perform_step!(integrator, cache::RKMK4Cache, repeat_step = false)
-    @unpack t, dt, uprev, u, p = integrator
+    (; t, dt, uprev, u, p) = integrator
     alg = unwrap_alg(integrator, nothing)
-    @unpack W, k, tmp, exp_cache = cache
+    (; W, k, tmp, exp_cache) = cache
     mass_matrix = integrator.f.mass_matrix
     exp_method = ExpMethodGeneric()
 
@@ -135,9 +135,9 @@ function initialize!(integrator, cache::RKMK2Cache)
 end
 
 function perform_step!(integrator, cache::RKMK2Cache, repeat_step = false)
-    @unpack t, dt, uprev, u, p = integrator
+    (; t, dt, uprev, u, p) = integrator
     alg = unwrap_alg(integrator, nothing)
-    @unpack W, k, tmp, exp_cache = cache
+    (; W, k, tmp, exp_cache) = cache
     mass_matrix = integrator.f.mass_matrix
     exp_method = ExpMethodGeneric()
 
@@ -168,8 +168,8 @@ function initialize!(integrator, cache::CG3Cache)
 end
 
 function perform_step!(integrator, cache::CG3Cache, repeat_step = false)
-    @unpack t, dt, uprev, u, p = integrator
-    @unpack W, k, tmp, exp_cache = cache
+    (; t, dt, uprev, u, p) = integrator
+    (; W, k, tmp, exp_cache) = cache
     mass_matrix = integrator.f.mass_matrix
     exp_method = ExpMethodGeneric()
 
@@ -203,8 +203,8 @@ function initialize!(integrator, cache::CG2Cache)
 end
 
 function perform_step!(integrator, cache::CG2Cache, repeat_step = false)
-    @unpack t, dt, uprev, u, p = integrator
-    @unpack W, k, tmp, exp_cache = cache
+    (; t, dt, uprev, u, p) = integrator
+    (; W, k, tmp, exp_cache) = cache
     mass_matrix = integrator.f.mass_matrix
     exp_method = ExpMethodGeneric()
 
@@ -231,8 +231,8 @@ function initialize!(integrator, cache::CG4aCache)
 end
 
 function perform_step!(integrator, cache::CG4aCache, repeat_step = false)
-    @unpack t, dt, uprev, u, p, alg = integrator
-    @unpack W, k, tmp, exp_cache = cache
+    (; t, dt, uprev, u, p, alg) = integrator
+    (; W, k, tmp, exp_cache) = cache
     mass_matrix = integrator.f.mass_matrix
     exp_method = ExpMethodGeneric()
 
@@ -278,8 +278,8 @@ function initialize!(integrator, cache::MagnusAdapt4Cache)
 end
 
 function perform_step!(integrator, cache::MagnusAdapt4Cache, repeat_step = false)
-    @unpack t, dt, uprev, u, p = integrator
-    @unpack W, k, tmp, utilde, atmp, exp_cache = cache
+    (; t, dt, uprev, u, p) = integrator
+    (; W, k, tmp, utilde, atmp, exp_cache) = cache
     mass_matrix = integrator.f.mass_matrix
     exp_method = ExpMethodGeneric()
 
@@ -346,9 +346,9 @@ function initialize!(integrator, cache::MagnusNC8Cache)
 end
 
 function perform_step!(integrator, cache::MagnusNC8Cache, repeat_step = false)
-    @unpack t, dt, uprev, u, p = integrator
+    (; t, dt, uprev, u, p) = integrator
     alg = unwrap_alg(integrator, nothing)
-    @unpack W, k, tmp, exp_cache = cache
+    (; W, k, tmp, exp_cache) = cache
     mass_matrix = integrator.f.mass_matrix
     exp_method = ExpMethodGeneric()
 
@@ -421,9 +421,9 @@ function initialize!(integrator, cache::MagnusGL4Cache)
 end
 
 function perform_step!(integrator, cache::MagnusGL4Cache, repeat_step = false)
-    @unpack t, dt, uprev, u, p = integrator
+    (; t, dt, uprev, u, p) = integrator
     alg = unwrap_alg(integrator, nothing)
-    @unpack W, k, tmp, exp_cache = cache
+    (; W, k, tmp, exp_cache) = cache
     mass_matrix = integrator.f.mass_matrix
     exp_method = ExpMethodGeneric()
 
@@ -456,9 +456,9 @@ function initialize!(integrator, cache::MagnusGL8Cache)
 end
 
 function perform_step!(integrator, cache::MagnusGL8Cache, repeat_step = false)
-    @unpack t, dt, uprev, u, p = integrator
+    (; t, dt, uprev, u, p) = integrator
     alg = unwrap_alg(integrator, nothing)
-    @unpack W, k, tmp, exp_cache = cache
+    (; W, k, tmp, exp_cache) = cache
     mass_matrix = integrator.f.mass_matrix
     exp_method = ExpMethodGeneric()
 
@@ -523,9 +523,9 @@ function initialize!(integrator, cache::MagnusNC6Cache)
 end
 
 function perform_step!(integrator, cache::MagnusNC6Cache, repeat_step = false)
-    @unpack t, dt, uprev, u, p = integrator
+    (; t, dt, uprev, u, p) = integrator
     alg = unwrap_alg(integrator, nothing)
-    @unpack W, k, tmp, exp_cache = cache
+    (; W, k, tmp, exp_cache) = cache
     mass_matrix = integrator.f.mass_matrix
     exp_method = ExpMethodGeneric()
 
@@ -570,9 +570,9 @@ function initialize!(integrator, cache::MagnusGL6Cache)
 end
 
 function perform_step!(integrator, cache::MagnusGL6Cache, repeat_step = false)
-    @unpack t, dt, uprev, u, p = integrator
+    (; t, dt, uprev, u, p) = integrator
     alg = unwrap_alg(integrator, nothing)
-    @unpack W, k, tmp, exp_cache = cache
+    (; W, k, tmp, exp_cache) = cache
     mass_matrix = integrator.f.mass_matrix
     exp_method = ExpMethodGeneric()
 
@@ -613,9 +613,9 @@ function initialize!(integrator, cache::MagnusGauss4Cache)
 end
 
 function perform_step!(integrator, cache::MagnusGauss4Cache, repeat_step = false)
-    @unpack t, dt, uprev, u, p = integrator
+    (; t, dt, uprev, u, p) = integrator
     alg = unwrap_alg(integrator, nothing)
-    @unpack W, k, tmp, exp_cache = cache
+    (; W, k, tmp, exp_cache) = cache
     mass_matrix = integrator.f.mass_matrix
     exp_method = ExpMethodGeneric()
 
@@ -650,9 +650,9 @@ function initialize!(integrator, cache::LieEulerCache)
 end
 
 function perform_step!(integrator, cache::LieEulerCache, repeat_step = false)
-    @unpack t, dt, uprev, u, p = integrator
+    (; t, dt, uprev, u, p) = integrator
     alg = unwrap_alg(integrator, nothing)
-    @unpack W, k, tmp, exp_cache = cache
+    (; W, k, tmp, exp_cache) = cache
     mass_matrix = integrator.f.mass_matrix
     exp_method = ExpMethodGeneric()
 
@@ -682,9 +682,9 @@ end
 
 function perform_step!(integrator, cache::MagnusLeapfrogCache, repeat_step = false,
         alg_extrapolates = true, iter = 1)
-    @unpack t, dt, uprev, uprev2, u, p, iter = integrator
+    (; t, dt, uprev, uprev2, u, p, iter) = integrator
     alg = unwrap_alg(integrator, nothing)
-    @unpack W, k, tmp, exp_cache = cache
+    (; W, k, tmp, exp_cache) = cache
     mass_matrix = integrator.f.mass_matrix
     exp_method = ExpMethodGeneric()
     # println("iter   : $iter")
@@ -733,7 +733,7 @@ end
 
 function perform_step!(integrator, cache::LinearExponentialConstantCache,
         repeat_step = false)
-    @unpack t, dt, uprev, f, p = integrator
+    (; t, dt, uprev, f, p) = integrator
     alg = unwrap_alg(integrator, nothing)
     A = convert(AbstractMatrix, f.f) # assume f to be an ODEFunction wrapped around a linear operator
 
@@ -771,8 +771,8 @@ function initialize!(integrator, cache::LinearExponentialCache)
 end
 
 function perform_step!(integrator, cache::LinearExponentialCache, repeat_step = false)
-    @unpack t, dt, uprev, u, f, p = integrator
-    @unpack tmp, KsCache, exp_cache = cache
+    (; t, dt, uprev, u, f, p) = integrator
+    (; tmp, KsCache, exp_cache) = cache
     alg = unwrap_alg(integrator, nothing)
     exp_method = ExpMethodGeneric()
     A = convert(AbstractMatrix, f.f) # assume f to be an ODEFunction wrapped around a linear operator
@@ -817,7 +817,7 @@ function initialize!(integrator, cache::CayleyEulerConstantCache)
 end
 
 function perform_step!(integrator, cache::CayleyEulerConstantCache, repeat_step = false)
-    @unpack t, dt, uprev, u, f, p = integrator
+    (; t, dt, uprev, u, f, p) = integrator
 
     if f isa SplitFunction
         A = f.f1.f
@@ -850,8 +850,8 @@ function initialize!(integrator, cache::CayleyEulerCache)
 end
 
 function perform_step!(integrator, cache::CayleyEulerCache, repeat_step = false)
-    @unpack t, dt, uprev, u, p, f = integrator
-    @unpack k, V, tmp = cache
+    (; t, dt, uprev, u, p, f) = integrator
+    (; k, V, tmp) = cache
     mass_matrix = integrator.f.mass_matrix
 
     if f isa SplitFunction
